@@ -4,8 +4,8 @@ import (
 	"fmt"
 
 	"github.com/git-town/git-town/v14/src/cli/dialog/components"
+	"github.com/git-town/git-town/v14/src/cli/dialog/components/list"
 	"github.com/git-town/git-town/v14/src/config/configdomain"
-	"github.com/git-town/git-town/v14/src/gohacks/stringers"
 	"github.com/git-town/git-town/v14/src/messages"
 )
 
@@ -21,15 +21,15 @@ Only change this if your code hosting server uses as custom URL.
 )
 
 func HostingPlatform(existingValue configdomain.HostingPlatform, inputs components.TestInput) (configdomain.HostingPlatform, bool, error) {
-	entries := []hostingPlatformEntry{
+	entries := hostingPlatformEntries{
 		hostingPlatformAutoDetect,
 		hostingPlatformBitBucket,
 		hostingPlatformGitea,
 		hostingPlatformGitHub,
 		hostingPlatformGitLab,
 	}
-	cursor := indexOfHostingPlatform(existingValue, entries)
-	newValue, aborted, err := components.RadioList(entries, cursor, hostingPlatformTitle, HostingPlatformHelp, inputs)
+	cursor := entries.IndexOfHostingPlatformOrStart(existingValue)
+	newValue, aborted, err := components.RadioList(list.NewEntries(entries...), cursor, hostingPlatformTitle, HostingPlatformHelp, inputs)
 	fmt.Printf(messages.CodeHosting, components.FormattedSelection(newValue.String(), aborted))
 	return newValue.HostingPlatform(), aborted, err
 }
@@ -40,12 +40,12 @@ const (
 	hostingPlatformAutoDetect hostingPlatformEntry = "auto-detect"
 	hostingPlatformBitBucket  hostingPlatformEntry = "BitBucket"
 	hostingPlatformGitea      hostingPlatformEntry = "Gitea"
-	hostingPlatformGitHub     hostingPlatformEntry = "Github"
+	hostingPlatformGitHub     hostingPlatformEntry = "GitHub"
 	hostingPlatformGitLab     hostingPlatformEntry = "GitLab"
 )
 
-func (self hostingPlatformEntry) HostingPlatform() configdomain.HostingPlatform {
-	switch self {
+func (hpe hostingPlatformEntry) HostingPlatform() configdomain.HostingPlatform {
+	switch hpe {
 	case hostingPlatformAutoDetect:
 		return configdomain.HostingPlatformNone
 	case hostingPlatformBitBucket:
@@ -57,30 +57,20 @@ func (self hostingPlatformEntry) HostingPlatform() configdomain.HostingPlatform
 	case hostingPlatformGitLab:
 		return configdomain.HostingPlatformGitLab
 	}
-	panic("unknown hosting platform: " + self)
+	panic("unknown hosting platform: " + hpe)
 }
 
-func (self hostingPlatformEntry) String() string {
-	return string(self)
+func (hpe hostingPlatformEntry) String() string {
+	return string(hpe)
 }
 
-func indexOfHostingPlatform(hostingPlatform configdomain.HostingPlatform, entries []hostingPlatformEntry) int {
-	entry := newHostingPlatformEntry(hostingPlatform)
-	return stringers.IndexOrStart(entries, entry)
-}
+type hostingPlatformEntries []hostingPlatformEntry
 
-func newHostingPlatformEntry(hosting configdomain.HostingPlatform) hostingPlatformEntry {
-	switch hosting {
-	case configdomain.HostingPlatformNone:
-		return hostingPlatformAutoDetect
-	case configdomain.HostingPlatformBitbucket:
-		return hostingPlatformBitBucket
-	case configdomain.HostingPlatformGitea:
-		return hostingPlatformGitea
-	case configdomain.HostingPlatformGitHub:
-		return hostingPlatformGitHub
-	case configdomain.HostingPlatformGitLab:
-		return hostingPlatformGitLab
+func (hpes hostingPlatformEntries) IndexOfHostingPlatformOrStart(needle configdomain.HostingPlatform) int {
+	for h, hostingPlatformEntry := range hpes {
+		if hostingPlatformEntry.HostingPlatform() == needle {
+			return h
+		}
 	}
-	panic("unknown hosting: " + hosting)
+	return 0
 }
