@@ -5,32 +5,49 @@ import (
 	"strings"
 
 	tea "github.com/charmbracelet/bubbletea"
+	"github.com/git-town/git-town/v14/src/cli/colors"
 	"github.com/git-town/git-town/v14/src/cli/dialog/components"
+	"github.com/git-town/git-town/v14/src/cli/dialog/components/list"
 	"github.com/git-town/git-town/v14/src/config/configdomain"
 	"github.com/git-town/git-town/v14/src/git/gitdomain"
 	"github.com/git-town/git-town/v14/src/gohacks/slice"
+	"github.com/git-town/git-town/v14/src/messages"
+	"github.com/muesli/termenv"
 	"golang.org/x/exp/maps"
 )
 
-func SwitchBranch(localBranches gitdomain.LocalBranchNames, initialBranch gitdomain.LocalBranchName, lineage configdomain.Lineage) (gitdomain.LocalBranchName, bool, error) {
-	entries := SwitchBranchEntries(localBranches, lineage)
+type SwitchBranchEntry struct {
+	Branch        gitdomain.LocalBranchName
+	Indentation   string
+	OtherWorktree bool
+}
+
+func (sbe SwitchBranchEntry) String() string {
+	return sbe.Indentation + sbe.Branch.String()
+}
+
+func SwitchBranch(localBranches gitdomain.LocalBranchNames, initialBranch gitdomain.LocalBranchName, lineage configdomain.Lineage, allBranches gitdomain.BranchInfos, uncommittedChanges bool, inputs components.TestInput) (gitdomain.LocalBranchName, bool, error) {
+	entries := SwitchBranchEntries(localBranches, lineage, allBranches)
 	cursor := SwitchBranchCursorPos(entries, initialBranch)
-	dialogProcess := tea.NewProgram(SwitchModel{
-		BubbleList:       components.NewBubbleList(entries, cursor),
-		InitialBranchPos: cursor,
+	dialogProgram := tea.NewProgram(SwitchModel{
+		InitialBranchPos:   cursor,
+		List:               list.NewList(newSwitchBranchListEntries(entries), cursor),
+		UncommittedChanges: uncommittedChanges,
 	})
-	dialogResult, err := dialogProcess.Run()
+	components.SendInputs(inputs, dialogProgram)
+	dialogResult, err := dialogProgram.Run()
 	if err != nil {
 		return "", false, err
 	}
 	result := dialogResult.(SwitchModel) //nolint:forcetypeassert
-	selectedEntry := result.BubbleList.SelectedEntry()
-	return selectedEntry.Branch, result.Aborted(), nil
+	selectedData := result.List.SelectedData()
+	return selectedData.Branch, result.Aborted(), nil
 }
 
 type SwitchModel struct {
-	components.BubbleList[SwitchBranchEntry]
-	InitialBranchPos int // position of the currently checked out branch in the list
+	list.List[SwitchBranchEntry]
+	InitialBranchPos   int  // position of the currently checked out branch in the list
+	UncommittedChanges bool // whether the workspace has uncommitted changes
 }
 
 func (self SwitchModel) Init() tea.Cmd {
@@ -42,39 +59,60 @@ func (self SwitchModel) Update(msg tea.Msg) (tea.Model, tea.Cmd) { //nolint:iret
 	if !isKeyMsg {
 		return self, nil
 	}
-	if handled, code := self.BubbleList.HandleKey(keyMsg); handled {
+	if handled, code := self.List.HandleKey(keyMsg); handled {
 		return self, code
 	}
 	if keyMsg.Type == tea.KeyEnter {
-		self.Status = components.StatusDone
+		self.Status = list.StatusDone
 		return self, tea.Quit
 	}
 	if keyMsg.String() == "o" {
-		self.Status = components.StatusDone
+		self.Status = list.StatusDone
 		return self, tea.Quit
 	}
 	return self, nil
 }
 
 func (self SwitchModel) View() string {
-	if self.Status != components.StatusActive {
+	if self.Status != list.StatusActive {
 		return ""
 	}
 	s := strings.Builder{}
+	if self.UncommittedChanges {
+		s.WriteString("\n")
+		s.WriteString(colors.BoldCyan().Styled(messages.SwitchUncommittedChanges))
+		s.WriteString("\n")
+	}
 	window := slice.Window(slice.WindowArgs{
 		CursorPos:    self.Cursor,
 		ElementCount: len(self.Entries),
 		WindowSize:   components.WindowSize,
 	})
 	for i := window.StartRow; i < window.EndRow; i++ {
-		branch := self.Entries[i]
+		entry := self.Entries[i]
+		isSelected := i == self.Cursor
+		isInitial := i == self.InitialBranchPos
 		switch {
-		case i == self.Cursor:
-			s.WriteString(self.Colors.Selection.Styled("> " + branch.String()))
-		case i == self.InitialBranchPos:
-			s.WriteString(self.Colors.Initial.Styled("* " + branch.String()))
+		case isSelected:
+			color := self.Colors.Selection
+			if entry.Data.OtherWorktree {
+				color = color.Faint()
+			}
+			s.WriteString(color.Styled("> " + entry.Text))
+		case isInitial:
+			color := self.Colors.Initial
+			if entry.Data.OtherWorktree {
+				color = color.Faint()
+			}
+			s.WriteString(color.Styled("* " + entry.Text))
+		case entry.Data.OtherWorktree:
+			s.WriteString(colors.Faint().Styled("+ " + entry.Text))
 		default:
-			s.WriteString("  " + branch.String())
+			color := termenv.String()
+			if entry.Data.OtherWorktree {
+				color = color.Faint()
+			}
+			s.WriteString(color.Styled("  " + entry.Text))
 		}
 		s.WriteRune('\n')
 	}
@@ -125,12 +163,12 @@ func SwitchBranchCursorPos(entries []SwitchBranchEntry, initialBranch gitdomain.
 }
 
 // SwitchBranchEntries provides the entries for the "switch branch" components.
-func SwitchBranchEntries(localBranches gitdomain.LocalBranchNames, lineage configdomain.Lineage) []SwitchBranchEntry {
+func SwitchBranchEntries(localBranches gitdomain.LocalBranchNames, lineage configdomain.Lineage, allBranches gitdomain.BranchInfos) []SwitchBranchEntry {
 	entries := make([]SwitchBranchEntry, 0, len(lineage))
 	roots := lineage.Roots()
 	// add all entries from the lineage
 	for _, root := range roots {
-		layoutBranches(&entries, root, "", lineage)
+		layoutBranches(&entries, root, "", lineage, allBranches)
 	}
 	// add missing local branches
 	branchesInLineage := maps.Keys(lineage)
@@ -141,25 +179,44 @@ func SwitchBranchEntries(localBranches gitdomain.LocalBranchNames, lineage confi
 		if slices.Contains(branchesInLineage, localBranch) {
 			continue
 		}
-		entries = append(entries, SwitchBranchEntry{Branch: localBranch, Indentation: ""})
+		branchInfo := allBranches.FindByLocalName(localBranch)
+		var otherWorktree bool
+		if branchInfo == nil {
+			otherWorktree = false
+		} else {
+			otherWorktree = branchInfo.SyncStatus == gitdomain.SyncStatusOtherWorktree
+		}
+		entries = append(entries, SwitchBranchEntry{Branch: localBranch, Indentation: "", OtherWorktree: otherWorktree})
 	}
 	return entries
 }
 
 // layoutBranches adds entries for the given branch and its children to the given entry list.
 // The entries are indented according to their position in the given lineage.
-func layoutBranches(result *[]SwitchBranchEntry, branch gitdomain.LocalBranchName, indentation string, lineage configdomain.Lineage) {
-	*result = append(*result, SwitchBranchEntry{Branch: branch, Indentation: indentation})
+func layoutBranches(result *[]SwitchBranchEntry, branch gitdomain.LocalBranchName, indentation string, lineage configdomain.Lineage, allBranches gitdomain.BranchInfos) {
+	if allBranches.HasLocalBranch(branch) || allBranches.HasMatchingTrackingBranchFor(branch) {
+		branchInfo := allBranches.FindByLocalName(branch)
+		var otherWorktree bool
+		if branchInfo == nil {
+			otherWorktree = false
+		} else {
+			otherWorktree = branchInfo.SyncStatus == gitdomain.SyncStatusOtherWorktree
+		}
+		*result = append(*result, SwitchBranchEntry{Branch: branch, Indentation: indentation, OtherWorktree: otherWorktree})
+	}
 	for _, child := range lineage.Children(branch) {
-		layoutBranches(result, child, indentation+"  ", lineage)
+		layoutBranches(result, child, indentation+"  ", lineage, allBranches)
 	}
 }
 
-type SwitchBranchEntry struct {
-	Branch      gitdomain.LocalBranchName
-	Indentation string
-}
-
-func (sbe SwitchBranchEntry) String() string {
-	return sbe.Indentation + sbe.Branch.String()
+func newSwitchBranchListEntries(switchBranchEntries []SwitchBranchEntry) list.Entries[SwitchBranchEntry] {
+	result := make(list.Entries[SwitchBranchEntry], len(switchBranchEntries))
+	for e, entry := range switchBranchEntries {
+		result[e] = list.Entry[SwitchBranchEntry]{
+			Data:    entry,
+			Enabled: !entry.OtherWorktree,
+			Text:    entry.String(),
+		}
+	}
+	return result
 }
