@@ -2,9 +2,11 @@ package debug
 
 import (
 	"fmt"
+	"os"
 	"strconv"
 
 	"github.com/git-town/git-town/v14/src/cli/dialog"
+	"github.com/git-town/git-town/v14/src/cli/dialog/components"
 	"github.com/git-town/git-town/v14/src/config/configdomain"
 	"github.com/git-town/git-town/v14/src/git/gitdomain"
 	"github.com/spf13/cobra"
@@ -20,11 +22,15 @@ func switchBranch() *cobra.Command {
 				return err
 			}
 			localBranches := gitdomain.LocalBranchNames{}
+			branchInfos := gitdomain.BranchInfos{}
 			for i := 0; i < int(amount); i++ {
-				localBranches = append(localBranches, gitdomain.NewLocalBranchName(fmt.Sprintf("branch-%d", i)))
+				branchName := gitdomain.NewLocalBranchName(fmt.Sprintf("branch-%d", i))
+				localBranches = append(localBranches, branchName)
+				branchInfos = append(branchInfos, gitdomain.BranchInfo{LocalName: branchName, SyncStatus: gitdomain.SyncStatusLocalOnly}) //nolint:exhaustruct
 			}
 			lineage := configdomain.Lineage{}
-			_, _, err = dialog.SwitchBranch(localBranches, gitdomain.NewLocalBranchName("branch-2"), lineage)
+			dialogTestInputs := components.LoadTestInputs(os.Environ())
+			_, _, err = dialog.SwitchBranch(localBranches, gitdomain.NewLocalBranchName("branch-2"), lineage, branchInfos, true, dialogTestInputs.Next())
 			return err
 		},
 	}
