@@ -101,6 +101,7 @@ type killConfig struct {
 	dryRun           bool
 	hasOpenChanges   bool
 	initialBranch    gitdomain.LocalBranchName
+	parentBranch     *gitdomain.LocalBranchName
 	previousBranch   gitdomain.LocalBranchName
 }
 
@@ -111,9 +112,9 @@ func determineKillConfig(args []string, repo *execute.OpenRepoResult, dryRun, ve
 		return nil, gitdomain.EmptyBranchesSnapshot(), 0, false, err
 	}
 	branchesSnapshot, stashSize, exit, err := execute.LoadRepoSnapshot(execute.LoadRepoSnapshotArgs{
+		Config:                repo.Runner.Config,
 		DialogTestInputs:      dialogTestInputs,
 		Fetch:                 true,
-		FullConfig:            &repo.Runner.Config.FullConfig,
 		HandleUnfinishedState: false,
 		Repo:                  repo,
 		RepoStatus:            repoStatus,
@@ -133,11 +134,13 @@ func determineKillConfig(args []string, repo *execute.OpenRepoResult, dryRun, ve
 		return nil, branchesSnapshot, stashSize, exit, fmt.Errorf(messages.KillBranchOtherWorktree, branchNameToKill)
 	}
 	if branchToKill.IsLocal() {
-		err = execute.EnsureKnownBranchAncestry(branchToKill.LocalName, execute.EnsureKnownBranchAncestryArgs{
-			Config:           &repo.Runner.Config.FullConfig,
-			AllBranches:      branchesSnapshot.Branches,
-			DefaultBranch:    repo.Runner.Config.FullConfig.MainBranch,
+		err = execute.EnsureKnownBranchesAncestry(execute.EnsureKnownBranchesAncestryArgs{
+			BranchesToVerify: gitdomain.LocalBranchNames{branchToKill.LocalName},
+			Config:           repo.Runner.Config,
+			DefaultChoice:    repo.Runner.Config.FullConfig.MainBranch,
 			DialogTestInputs: &dialogTestInputs,
+			LocalBranches:    branchesSnapshot.Branches,
+			MainBranch:       repo.Runner.Config.FullConfig.MainBranch,
 			Runner:           repo.Runner,
 		})
 		if err != nil {
@@ -156,6 +159,7 @@ func determineKillConfig(args []string, repo *execute.OpenRepoResult, dryRun, ve
 	} else {
 		branchWhenDone = branchesSnapshot.Active
 	}
+	parentBranch := repo.Runner.Config.FullConfig.Lineage.Parent(branchToKill.LocalName)
 	return &killConfig{
 		FullConfig:       &repo.Runner.Config.FullConfig,
 		branchNameToKill: *branchToKill,
@@ -165,14 +169,11 @@ func determineKillConfig(args []string, repo *execute.OpenRepoResult, dryRun, ve
 		dryRun:           dryRun,
 		hasOpenChanges:   repoStatus.OpenChanges,
 		initialBranch:    branchesSnapshot.Active,
+		parentBranch:     &parentBranch,
 		previousBranch:   previousBranch,
 	}, branchesSnapshot, stashSize, false, nil
 }
 
-func (self killConfig) branchToKillParent() gitdomain.LocalBranchName {
-	return self.Lineage.Parent(self.branchNameToKill.LocalName)
-}
-
 func killProgram(config *killConfig) (runProgram, finalUndoProgram program.Program) {
 	prog := program.Program{}
 	switch config.branchTypeToKill {
@@ -214,11 +215,11 @@ func killLocalBranch(prog *program.Program, finalUndoProgram *program.Program, c
 		prog.Add(&opcodes.Checkout{Branch: config.branchWhenDone})
 	}
 	prog.Add(&opcodes.DeleteLocalBranch{Branch: config.branchNameToKill.LocalName})
-	if !config.dryRun {
+	if !config.dryRun && config.parentBranch != nil {
 		sync.RemoveBranchFromLineage(sync.RemoveBranchFromLineageArgs{
 			Branch:  config.branchNameToKill.LocalName,
 			Lineage: config.Lineage,
-			Parent:  config.branchToKillParent(),
+			Parent:  *config.parentBranch,
 			Program: prog,
 		})
 	}
