@@ -66,7 +66,7 @@ func determineRepoConfig(repo *execute.OpenRepoResult) (*repoConfig, error) {
 		return nil, err
 	}
 	dialogInputs := components.LoadTestInputs(os.Environ())
-	err = validate.IsConfigured(&repo.Runner.Backend, &repo.Runner.Config.FullConfig, branchesSnapshot.Branches.LocalBranches().Names(), &dialogInputs)
+	err = validate.IsConfigured(&repo.Runner.Backend, repo.Runner.Config, branchesSnapshot.Branches.LocalBranches().Names(), &dialogInputs)
 	if err != nil {
 		return nil, err
 	}
