@@ -4,6 +4,7 @@
 package config
 
 import (
+	"errors"
 	"fmt"
 	"strconv"
 
@@ -54,6 +55,19 @@ func (self *Config) AddToPerennialBranches(branches ...gitdomain.LocalBranchName
 	return self.SetPerennialBranches(append(self.FullConfig.PerennialBranches, branches...))
 }
 
+// Author provides the locally Git configured user.
+func (self *Config) Author() (gitdomain.Author, error) {
+	email := self.FullConfig.GitUserEmail
+	if email == "" {
+		return "", errors.New(messages.GitUserEmailMissing)
+	}
+	name := self.FullConfig.GitUserName
+	if name == "" {
+		return "", errors.New(messages.GitUserEmailMissing)
+	}
+	return gitdomain.Author(name + " <" + email + ">"), nil
+}
+
 // OriginURL provides the URL for the "origin" remote.
 // Tests can stub this through the GIT_TOWN_REMOTE environment variable.
 // Caches its result so can be called repeatedly.
@@ -109,6 +123,18 @@ func (self *Config) RemoveMainBranch() {
 	_ = self.GitConfig.RemoveLocalConfigValue(gitconfig.KeyMainBranch)
 }
 
+// RemoveOutdatedConfiguration removes outdated Git Town configuration.
+func (self *Config) RemoveOutdatedConfiguration(localBranches gitdomain.LocalBranchNames) error {
+	for child, parent := range self.FullConfig.Lineage {
+		hasChildBranch := localBranches.Contains(child)
+		hasParentBranch := localBranches.Contains(parent)
+		if !hasChildBranch || !hasParentBranch {
+			self.RemoveParent(child)
+		}
+	}
+	return nil
+}
+
 // RemoveParent removes the parent branch entry for the given branch from the Git configuration.
 func (self *Config) RemoveParent(branch gitdomain.LocalBranchName) {
 	if self.LocalGitConfig.Lineage != nil {
