@@ -6,6 +6,7 @@ import (
 	"os/exec"
 	"strings"
 
+	"github.com/git-town/git-town/v14/src/cli/colors"
 	"github.com/git-town/git-town/v14/src/config/configdomain"
 	"github.com/git-town/git-town/v14/src/git/gitdomain"
 	"github.com/git-town/git-town/v14/src/messages"
@@ -179,7 +180,7 @@ func (self *Access) SetLocalConfigValue(key Key, value string) error {
 }
 
 func (self *Access) UpdateDeprecatedGlobalSetting(oldKey, newKey Key, value string) {
-	fmt.Printf(messages.SettingDeprecatedGlobalMessage, oldKey, newKey)
+	fmt.Println(colors.Cyan().Styled(fmt.Sprintf(messages.SettingDeprecatedGlobalMessage, oldKey, newKey)))
 	err := self.RemoveGlobalConfigValue(oldKey)
 	if err != nil {
 		fmt.Printf(messages.SettingGlobalCannotRemove, oldKey, err)
@@ -191,7 +192,7 @@ func (self *Access) UpdateDeprecatedGlobalSetting(oldKey, newKey Key, value stri
 }
 
 func (self *Access) UpdateDeprecatedLocalSetting(oldKey, newKey Key, value string) {
-	fmt.Printf(messages.SettingLocalDeprecatedMessage, oldKey, newKey)
+	fmt.Println(colors.Cyan().Styled(fmt.Sprintf(messages.SettingLocalDeprecatedMessage, oldKey, newKey)))
 	err := self.RemoveLocalConfigValue(oldKey)
 	if err != nil {
 		fmt.Printf(messages.SettingLocalCannotRemove, oldKey, err)
@@ -232,26 +233,36 @@ func (self *Access) load(global bool, updateOutdated bool) (SingleSnapshot, conf
 		}
 		parts := strings.SplitN(line, "\n", 2)
 		key, value := parts[0], parts[1]
-		configKey := ParseKey(key)
-		if configKey == nil {
+		configKeyPtr := ParseKey(key)
+		if configKeyPtr == nil {
 			continue
 		}
+		configKey := *configKeyPtr
 		if updateOutdated {
-			newKey, keyIsDeprecated := DeprecatedKeys[*configKey]
+			newKey, keyIsDeprecated := DeprecatedKeys[configKey]
 			if keyIsDeprecated {
-				self.UpdateDeprecatedSetting(*configKey, newKey, value, global)
-				configKey = &newKey
+				self.UpdateDeprecatedSetting(configKey, newKey, value, global)
+				configKey = newKey
 			}
-			if key != KeyPerennialBranches.String() && value == "" {
-				_ = self.RemoveLocalConfigValue(*configKey)
+			if configKey != KeyPerennialBranches && value == "" {
+				_ = self.RemoveLocalConfigValue(configKey)
 				continue
 			}
 		}
-		snapshot[*configKey] = value
-		err := AddKeyToPartialConfig(*configKey, value, &config)
+		snapshot[configKey] = value
+		err := AddKeyToPartialConfig(configKey, value, &config)
 		if err != nil {
 			return snapshot, config, err
 		}
 	}
+	// verify lineage
+	if updateOutdated && config.Lineage != nil {
+		for child, parent := range *config.Lineage {
+			if child == parent {
+				fmt.Println(colors.Cyan().Styled(fmt.Sprintf(messages.ConfigLineageParentIsChild, child)))
+				_ = self.RemoveLocalConfigValue(createLineageKey(child))
+			}
+		}
+	}
 	return snapshot, config, nil
 }
