@@ -180,12 +180,21 @@ func ParseKey(name string) *Key {
 	return nil
 }
 
+const (
+	LineageKeyPrefix = "git-town-branch."
+	LineageKeySuffix = ".parent"
+)
+
+func createLineageKey(branch gitdomain.LocalBranchName) Key {
+	return Key(LineageKeyPrefix + branch.String() + LineageKeySuffix)
+}
+
 func parseLineageKey(key string) *Key {
-	if !strings.HasPrefix(key, "git-town-branch.") || !strings.HasSuffix(key, ".parent") {
-		return nil
+	if strings.HasPrefix(key, LineageKeyPrefix) && strings.HasSuffix(key, LineageKeySuffix) {
+		result := Key(key)
+		return &result
 	}
-	result := Key(key)
-	return &result
+	return nil
 }
 
 // DeprecatedKeys defines the up-to-date counterparts to deprecated configuration settings.
