@@ -2,7 +2,7 @@ package execute
 
 import (
 	"github.com/git-town/git-town/v14/src/cli/dialog/components"
-	"github.com/git-town/git-town/v14/src/config/configdomain"
+	"github.com/git-town/git-town/v14/src/config"
 	"github.com/git-town/git-town/v14/src/git"
 	"github.com/git-town/git-town/v14/src/git/gitdomain"
 	"github.com/git-town/git-town/v14/src/validate"
@@ -17,9 +17,12 @@ import (
 func EnsureKnownBranchesAncestry(args EnsureKnownBranchesAncestryArgs) error {
 	updated, err := validate.KnowsBranchesAncestors(validate.KnowsBranchesAncestorsArgs{
 		Backend:          &args.Runner.Backend,
+		BranchesToVerify: args.BranchesToVerify,
 		Config:           args.Config,
+		DefaultChoice:    args.DefaultChoice,
 		DialogTestInputs: args.DialogTestInputs,
 		LocalBranches:    args.LocalBranches,
+		MainBranch:       args.MainBranch,
 	})
 	if err != nil {
 		return err
@@ -31,8 +34,11 @@ func EnsureKnownBranchesAncestry(args EnsureKnownBranchesAncestryArgs) error {
 }
 
 type EnsureKnownBranchesAncestryArgs struct {
-	Config           *configdomain.FullConfig
+	BranchesToVerify gitdomain.LocalBranchNames
+	Config           *config.Config
+	DefaultChoice    gitdomain.LocalBranchName
 	DialogTestInputs *components.TestInputs
 	LocalBranches    gitdomain.BranchInfos
+	MainBranch       gitdomain.LocalBranchName
 	Runner           *git.ProdRunner
 }
