@@ -3,7 +3,7 @@ package gitdomain_test
 import (
 	"testing"
 
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
 	"github.com/shoenig/test/must"
 )
 
@@ -31,7 +31,7 @@ func TestLocalBranchNames(t *testing.T) {
 	t.Run("AtRemote", func(t *testing.T) {
 		t.Parallel()
 		branch := gitdomain.NewLocalBranchName("branch")
-		have := branch.AtRemote(gitdomain.OriginRemote)
+		have := branch.AtRemote(gitdomain.RemoteOrigin)
 		want := gitdomain.NewRemoteBranchName("origin/branch")
 		must.EqOp(t, want, have)
 	})
@@ -98,6 +98,26 @@ func TestLocalBranchNames(t *testing.T) {
 		})
 	})
 
+	t.Run("Prepend", func(t *testing.T) {
+		t.Parallel()
+		t.Run("empty list", func(t *testing.T) {
+			t.Parallel()
+			branch := gitdomain.NewLocalBranchName("branch")
+			have := gitdomain.LocalBranchNames{}
+			have.Prepend(branch)
+			want := gitdomain.LocalBranchNames{branch}
+			must.Eq(t, want, have)
+		})
+		t.Run("populated list", func(t *testing.T) {
+			t.Parallel()
+			newBranch := gitdomain.NewLocalBranchName("new")
+			have := gitdomain.NewLocalBranchNames("one", "two")
+			have.Prepend(newBranch)
+			want := gitdomain.NewLocalBranchNames("new", "one", "two")
+			must.Eq(t, want, have)
+		})
+	})
+
 	t.Run("Remove", func(t *testing.T) {
 		t.Parallel()
 		t.Run("the element to remove exist in the list", func(t *testing.T) {
@@ -123,10 +143,10 @@ func TestLocalBranchNames(t *testing.T) {
 		})
 	})
 
-	t.Run("RemoveMarkers", func(t *testing.T) {
+	t.Run("RemoveWorktreeMarkers", func(t *testing.T) {
 		t.Parallel()
 		branches := gitdomain.NewLocalBranchNames("one", "+ two")
-		have := branches.RemoveWorkspaceMarkers()
+		have := branches.RemoveWorktreeMarkers()
 		want := gitdomain.NewLocalBranchNames("one", "two")
 		must.Eq(t, want, have)
 	})
