@@ -14,25 +14,32 @@ type Parts struct {
 }
 
 func Parse(url string) *Parts {
-	patterns := []string{
-		`^[^:]+://(?P<user>.*@)?(?P<host>.*\/)(?P<org>.*\/)(?P<repo>.*)\.git$`,
-		`^[^:]+://(?P<user>.*@)?(?P<host>.*\/)(?P<org>.*\/)(?P<repo>.*)$`,
-		`^(?P<user>.*@)?(?P<host>.*?[:/])(?P<org>.*\/)(?P<repo>.*)\.git$`,
-		`^(?P<user>.*@)?(?P<host>.*?[:/])(?P<org>.*\/)(?P<repo>.*)$`,
+	pattern := `^` +
+		// ignore transport protocol
+		`(?:[^:]+://)?` +
+		// capture "user@"
+		`(?P<user>.*@)?` +
+		// capture "host:" or "host/"
+		`(?P<host>.*?[:/])` +
+		// ignore the port
+		`(?:\d+\/)?` +
+		// capture "org/"
+		`(?P<org>.*\/)` +
+		// capture "repo"
+		`(?P<repo>.*?)` +
+		// ignore trailing ".git"
+		`(?:\.git)?$`
+	regex := regexp.MustCompile(pattern)
+	matches := regex.FindStringSubmatch(url)
+	if matches == nil {
+		return nil
 	}
-	for _, pattern := range patterns {
-		regex := regexp.MustCompile(pattern)
-		matches := regex.FindStringSubmatch(url)
-		if matches != nil {
-			return &Parts{
-				User: trimLast(matches[1]),
-				Host: trimLast(matches[2]),
-				Org:  trimLast(matches[3]),
-				Repo: matches[4],
-			}
-		}
+	return &Parts{
+		User: trimLast(matches[1]),
+		Host: trimLast(matches[2]),
+		Org:  trimLast(matches[3]),
+		Repo: matches[4],
 	}
-	return nil
 }
 
 // trimLast trims the last character of the given text.
