@@ -36,6 +36,7 @@ const (
 	CompletionTypeUnknown              = "unknown completion type: %q"
 	ConfigFileCannotRead               = "cannot read the configuration file %q: %w"
 	ConfigFileInvalidData              = "the configuration file %q does not contain TOML-formatted content: %w"
+	ConfigLineageParentIsChild         = "removing lineage entry for %q because the parent is the child"
 	ConfigMainbranchInConfigFile       = "please configure the main branch in the config file"
 	ConfigNeeded                       = "Git Town needs to be configured\n\n"
 	ConfigStorage                      = "Config storage: %s\n"
@@ -66,6 +67,7 @@ const (
 	FileStatProblem                    = "cannot check file %q: %w"
 	FileWriteProblem                   = "cannot write file %q: %w"
 	GiteaToken                         = "Gitea token: %s\n"
+	GitHubEnterpriseInitializeError    = "cannot initialize GitHub Enterprise client: %s"
 	GitHubToken                        = "GitHub token: %s\n"
 	GitLabToken                        = "GitLab token: %s\n"
 	GitOutputIrregular                 = `
@@ -158,47 +160,42 @@ nd will be removed in future versions of Git Town.`
 	RunstatePathProblem            = "cannot determine the runstate file path: %w"
 	RunstateSaveProblem            = "cannot save run state: %w"
 	SetParentNoFeatureBranch       = "the branch %q is not a feature branch. Only feature branches can have parent branches"
-	SettingDeprecatedGlobalMessage = `
-I found the deprecated global setting %q.
-I am upgrading this setting to the new format %q.
-`
-	SettingGlobalCannotRemove     = "ERROR: cannot remove global Git setting %q: %v"
-	SettingGlobalCannotWrite      = "ERROR: cannot write global Git setting %q: %v"
-	SettingIgnoreInvalid          = "Notice: ignoring invalid dialog input setting %q\n"
-	SettingLocalDeprecatedMessage = `
-I found the deprecated local setting %q.
-I am upgrading this setting to the new format %q.
-`
-	SettingLocalCannotRemove    = "ERROR: cannot remove local Git setting %q: %v"
-	SettingLocalCannotWrite     = "ERROR: cannot write local Git setting %q: %v"
-	ShipAbortedMergeError       = "aborted because commit exited with error"
-	ShipBranchOtherWorktree     = "branch %q is active in another worktree"
-	ShipBranchNothingToDo       = "the branch %q has no shippable changes"
-	ShipChildBranch             = "shipping this branch would ship %s as well,\nplease ship %q first"
-	ShipDeletesTrackingBranches = "Ship deletes tracking branches: %s\n"
-	ShipOpenChanges             = "you have uncommitted changes. Did you mean to commit them before shipping?"
-	ShippableChangesProblem     = "cannot determine whether branch %q has shippable changes: %w"
-	SkipBranchHasConflicts      = "cannot skip branch that resulted in conflicts"
-	SkipMessage                 = `You can run "git town skip" to skip the currently failing operation.`
-	SkipNothingToDo             = "nothing to skip"
-	SquashCannotReadFile        = "cannot read squash message file %q: %w"
-	SquashCommitAuthorQuery     = "Please choose an author for the squash commit:"
-	SquashCommitAuthorProblem   = "error getting squash commit author: %w"
-	SquashCommitAuthorSelection = "Selected squash commit author: %s\n"
-	SquashMessageProblem        = "cannot comment out the squash commit message: %w"
-	StatusFileNotFound          = "No status file found for this repository."
-	SyncBeforeShip              = "Sync before ship: %s\n"
-	SyncFeatureBranches         = "Sync feature branches: %s\n"
-	SyncPerennialBranches       = "Sync perennial branches: %s\n"
-	SyncStatusNotRecognized     = "cannot determine the sync status for Git remote %q and branch name %q"
-	SyncWithUpstream            = "Sync with upstream: %s\n"
-	UndoCreateOpcodeProblem     = "cannot create undo operations for %q: %w"
-	UndoMessage                 = `You can run "git town undo" to go back to where you started.`
-	UndoNothingToDo             = "nothing to undo"
-	UnfinishedCommandHandle     = "Handle unfinished command: %s\n"
-	UnfinishedRunStateContinue  = "Continue the \"%s\" command after having resolved conflicts"
-	UnfinishedRunStateDiscard   = "Discard the unfinished state and run the new command"
-	UnfinishedRunStateQuit      = "Quit without running anything"
-	UnfinishedRunStateSkip      = "Skip the current branch and continue the \"%s\" command on the next branch"
-	UnfinishedRunStateUndo      = "Undo the previous \"%s\" command"
+	SettingDeprecatedGlobalMessage = "Upgrading deprecated global setting %q to %q."
+	SettingGlobalCannotRemove      = "ERROR: cannot remove global Git setting %q: %v"
+	SettingGlobalCannotWrite       = "ERROR: cannot write global Git setting %q: %v"
+	SettingIgnoreInvalid           = "Notice: ignoring invalid dialog input setting %q\n"
+	SettingLocalDeprecatedMessage  = "Upgrading deprecated local setting %q to %q."
+	SettingLocalCannotRemove       = "ERROR: cannot remove local Git setting %q: %v"
+	SettingLocalCannotWrite        = "ERROR: cannot write local Git setting %q: %v"
+	ShipAbortedMergeError          = "aborted because commit exited with error"
+	ShipBranchOtherWorktree        = "branch %q is active in another worktree"
+	ShipBranchNothingToDo          = "the branch %q has no shippable changes"
+	ShipChildBranch                = "shipping this branch would ship %s as well,\nplease ship %q first"
+	ShipDeletesTrackingBranches    = "Ship deletes tracking branches: %s\n"
+	ShipOpenChanges                = "you have uncommitted changes. Did you mean to commit them before shipping?"
+	ShippableChangesProblem        = "cannot determine whether branch %q has shippable changes: %w"
+	SkipBranchHasConflicts         = "cannot skip branch that resulted in conflicts"
+	SkipMessage                    = `You can run "git town skip" to skip the currently failing operation.`
+	SkipNothingToDo                = "nothing to skip"
+	SquashCannotReadFile           = "cannot read squash message file %q: %w"
+	SquashCommitAuthorQuery        = "Please choose an author for the squash commit:"
+	SquashCommitAuthorProblem      = "error getting squash commit author: %w"
+	SquashCommitAuthorSelection    = "Selected squash commit author: %s\n"
+	SquashMessageProblem           = "cannot comment out the squash commit message: %w"
+	StatusFileNotFound             = "No status file found for this repository."
+	SwitchUncommittedChanges       = "uncommitted changes\n"
+	SyncBeforeShip                 = "Sync before ship: %s\n"
+	SyncFeatureBranches            = "Sync feature branches: %s\n"
+	SyncPerennialBranches          = "Sync perennial branches: %s\n"
+	SyncStatusNotRecognized        = "cannot determine the sync status for Git remote %q and branch name %q"
+	SyncWithUpstream               = "Sync with upstream: %s\n"
+	UndoCreateOpcodeProblem        = "cannot create undo operations for %q: %w"
+	UndoMessage                    = `You can run "git town undo" to go back to where you started.`
+	UndoNothingToDo                = "nothing to undo"
+	UnfinishedCommandHandle        = "Handle unfinished command: %s\n"
+	UnfinishedRunStateContinue     = "Continue the \"%s\" command after having resolved conflicts"
+	UnfinishedRunStateDiscard      = "Discard the unfinished state and run the new command"
+	UnfinishedRunStateQuit         = "Quit without running anything"
+	UnfinishedRunStateSkip         = "Skip the current branch and continue the \"%s\" command on the next branch"
+	UnfinishedRunStateUndo         = "Undo the previous \"%s\" command"
 )
