@@ -12,9 +12,6 @@ import (
 
 // finished is called when executing all steps has successfully finished.
 func finished(args ExecuteArgs) error {
-	if args.RunState.IsUndo {
-		return finishedUndoCommand(args)
-	}
 	var err error
 	args.RunState.EndBranchesSnapshot, err = args.Run.Backend.BranchesSnapshot()
 	if err != nil {
@@ -58,12 +55,3 @@ func finishedDryRunCommand(args ExecuteArgs) error {
 	print.Footer(args.Verbose, args.Run.CommandsCounter.Count(), args.Run.FinalMessages.Result())
 	return nil
 }
-
-func finishedUndoCommand(args ExecuteArgs) error {
-	err := statefile.Delete(args.RootDir)
-	if err != nil {
-		return fmt.Errorf(messages.RunstateDeleteProblem, err)
-	}
-	print.Footer(args.Verbose, args.Run.CommandsCounter.Count(), args.Run.FinalMessages.Result())
-	return nil
-}
