@@ -3,7 +3,7 @@ package light
 import (
 	"fmt"
 
-	"github.com/git-town/git-town/v14/src/cli/dialog/components"
+	"github.com/git-town/git-town/v14/src/cli/colors"
 	"github.com/git-town/git-town/v14/src/config/configdomain"
 	"github.com/git-town/git-town/v14/src/git"
 	"github.com/git-town/git-town/v14/src/vm/program"
@@ -22,7 +22,7 @@ func Execute(prog program.Program, runner *git.ProdRunner, lineage configdomain.
 			UpdateInitialBranchLocalSHA:     nil,
 		})
 		if err != nil {
-			fmt.Println(components.Red().Styled("NOTICE: " + err.Error()))
+			fmt.Println(colors.Red().Styled("NOTICE: " + err.Error()))
 		}
 	}
 }
