@@ -7,12 +7,12 @@ import (
 	"testing"
 
 	"github.com/acarl005/stripansi"
-	"github.com/git-town/git-town/v13/src/config/configdomain"
-	"github.com/git-town/git-town/v13/src/git/gitdomain"
-	"github.com/git-town/git-town/v13/test/filesystem"
-	"github.com/git-town/git-town/v13/test/fixture"
-	"github.com/git-town/git-town/v13/test/git"
-	"github.com/git-town/git-town/v13/test/testruntime"
+	"github.com/git-town/git-town/v14/src/config/configdomain"
+	"github.com/git-town/git-town/v14/src/git/gitdomain"
+	"github.com/git-town/git-town/v14/test/filesystem"
+	"github.com/git-town/git-town/v14/test/fixture"
+	"github.com/git-town/git-town/v14/test/git"
+	"github.com/git-town/git-town/v14/test/testruntime"
 	"github.com/shoenig/test/must"
 )
 
@@ -26,10 +26,10 @@ func TestTestCommands(t *testing.T) {
 		must.NoError(t, err)
 		must.Eq(t, gitdomain.Remotes{}, remotes)
 		origin := testruntime.Create(t)
-		dev.AddRemote(gitdomain.OriginRemote, origin.WorkingDir)
+		dev.AddRemote(gitdomain.RemoteOrigin, origin.WorkingDir)
 		remotes, err = dev.Remotes()
 		must.NoError(t, err)
-		must.Eq(t, gitdomain.Remotes{gitdomain.OriginRemote}, remotes)
+		must.Eq(t, gitdomain.Remotes{gitdomain.RemoteOrigin}, remotes)
 	})
 
 	t.Run("Commits", func(t *testing.T) {
@@ -67,7 +67,7 @@ func TestTestCommands(t *testing.T) {
 		repoDir := filepath.Join(t.TempDir(), "repo") // need a non-existing directory
 		filesystem.CopyDirectory(origin.WorkingDir, repoDir)
 		runtime := testruntime.New(repoDir, repoDir, "")
-		runtime.AddRemote(gitdomain.OriginRemote, origin.WorkingDir)
+		runtime.AddRemote(gitdomain.RemoteOrigin, origin.WorkingDir)
 		runtime.Fetch()
 		runtime.ConnectTrackingBranch(gitdomain.NewLocalBranchName("initial"))
 		runtime.PushBranch()
@@ -201,7 +201,7 @@ func TestTestCommands(t *testing.T) {
 		t.Parallel()
 		repo := testruntime.Create(t)
 		origin := testruntime.Create(t)
-		repo.AddRemote(gitdomain.OriginRemote, origin.WorkingDir)
+		repo.AddRemote(gitdomain.RemoteOrigin, origin.WorkingDir)
 		repo.Fetch()
 	})
 
@@ -243,7 +243,7 @@ func TestTestCommands(t *testing.T) {
 			runner.CreateFile("file1", "content")
 			runner.StageFiles("file1")
 			runner.CommitStagedChanges("stuff")
-			runner.PushBranchToRemote(gitdomain.NewLocalBranchName("branch1"), gitdomain.OriginRemote)
+			runner.PushBranchToRemote(gitdomain.NewLocalBranchName("branch1"), gitdomain.RemoteOrigin)
 			have, _ := runner.HasBranchesOutOfSync()
 			must.False(t, have)
 		})
@@ -343,9 +343,9 @@ func TestTestCommands(t *testing.T) {
 		t.Parallel()
 		dev := testruntime.Create(t)
 		origin := testruntime.Create(t)
-		dev.AddRemote(gitdomain.OriginRemote, origin.WorkingDir)
+		dev.AddRemote(gitdomain.RemoteOrigin, origin.WorkingDir)
 		dev.CreateBranch(gitdomain.NewLocalBranchName("b1"), gitdomain.NewLocalBranchName("initial"))
-		dev.PushBranchToRemote(gitdomain.NewLocalBranchName("b1"), gitdomain.OriginRemote)
+		dev.PushBranchToRemote(gitdomain.NewLocalBranchName("b1"), gitdomain.RemoteOrigin)
 		branches, err := origin.LocalBranchesMainFirst(gitdomain.NewLocalBranchName("initial"))
 		must.NoError(t, err)
 		want := gitdomain.NewLocalBranchNames("initial", "b1")
@@ -371,8 +371,8 @@ func TestTestCommands(t *testing.T) {
 		t.Parallel()
 		repo := testruntime.Create(t)
 		origin := testruntime.Create(t)
-		repo.AddRemote(gitdomain.OriginRemote, origin.WorkingDir)
-		repo.RemoveRemote(gitdomain.OriginRemote)
+		repo.AddRemote(gitdomain.RemoteOrigin, origin.WorkingDir)
+		repo.RemoveRemote(gitdomain.RemoteOrigin)
 		remotes, err := repo.Remotes()
 		must.NoError(t, err)
 		must.Len(t, 0, remotes)
